@@ -16,7 +16,7 @@ from IPython import get_ipython
 from IPython.display import publish_display_data
 
 
-class UnpicklableError(Exception):
+class UnpickleableError(Exception):
     """
     An exception to raise when :py:func:`pybryt.utils.pickle_and_hash` fails.
     """
@@ -33,17 +33,17 @@ def pickle_and_hash(obj: Any) -> str:
         ``str``: the hex digest of the SHA-512 hash of the pickled object
 
     Raises:
-        :py:class:`pybryt.utils.UnpicklableError`: if the object cannot be pickled
+        :py:class:`pybryt.utils.UnpickleableError`: if the object cannot be pickled
     """
     try:
         s = dill.dumps(obj)
     except:
-        raise UnpicklableError()
+        raise UnpickleableError()
 
     return hashlib.sha512(s).hexdigest()
 
 
-def filter_picklable_list(lst: List[Any]) -> None:
+def filter_pickleable_list(lst: List[Any]) -> None:
     """
     Removes all elements from a list that cannot be pickled with ``dill``.
 
